@@ -1,8 +1,10 @@
 
-import unittest, slapd
+import unittest
 import _ldap
 import logging
 
+from Tests import slapd
+
 reusable_server = None
 def get_reusable_server():
     global reusable_server
